package hdm.mi.growbros.service;

import hdm.mi.growbros.models.plant.Plant;
import hdm.mi.growbros.repositories.WishListRepository;
import lombok.RequiredArgsConstructor;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;


import java.time.LocalDate;
import java.time.temporal.TemporalField;
import java.time.temporal.WeekFields;
import java.util.Collection;
import java.util.List;
import java.util.Locale;


@Service
@RequiredArgsConstructor
public class WishListService {

    private final WishListRepository wishListRepository;
    public Collection<Plant> getWishedPlants() {
        //todo: check for current user
        return wishListRepository.findAll();
    }

    public List<Plant> sort(String sortKey) {
        switch (sortKey) {
            case ("name"):
                Sort sortByName = Sort.by(Sort.Direction.ASC, "name");
                return wishListRepository.findAll(sortByName);
            case ("addedOn"):
                Sort sortByDate = Sort.by(Sort.Direction.ASC, "addedOn");
                return wishListRepository.findAll(sortByDate);
            case ("plantWeek"):
                int currentWeek = getWeekNum(LocalDate.now());
                Sort sortByPlantWeek = Sort.by(Sort.Direction.ASC, "plantWeekStart");
                return wishListRepository.findAll(sortByPlantWeek);
            default:
                return wishListRepository.findAll();
        }
    }

    public int getWeekNum(LocalDate date) {

        WeekFields wf = WeekFields.of(Locale.getDefault()) ;                     // Use week fields appropriate to your locale. People in different places define a week and week-number differently, such as starting on a Monday or a Sunday, and so on.
        TemporalField weekNum = wf.weekOfWeekBasedYear();                        // Represent the idea of this locale’s definition of week number as a `TemporalField`.
        int week = Integer.parseInt(String.format("%02d", date.get(weekNum)));   // Using that locale’s definition of week number, determine the week-number for this particular `LocalDate` value.

        return week-1;  //because in class Plant weeks are indexed at 0
    }
}
